@@ -450,6 +450,8 @@ OE(["-f", "--flatten"], "Flatten pseudomodule members at start", var='doFlatten'
 OE(["-k", "--keep-going"], "Don't exit on errors; continue"),
 OE(["-e", "--ignore-errors"], "Ignore errors completely"),
 OE(["-r", "--raw-errors"], "Show full tracebacks of Python errors", var='rawErrors', env=em.RAW_ERRORS_ENV),
+OE(["--brief-errors"], "Don't show attributes when formatting errors"),
+OE(["--verbose-errors"], "Show attributes when formatting errors"),
 OE(["-i", "--interactive"], "Enter interactive mode after processing", var='goInteractive', env=em.INTERACTIVE_ENV),
 OE(["-d", "--delete-on-error"], "Delete output file on error\n"
                                 "(-o or -a needed)", var='deleteOnError', env=em.DELETE_ON_ERROR_ENV),
@@ -481,13 +483,16 @@ OE(["-F", "--file=FILENAME"], "Execute Python file before main file"),
 OE(["-G", "--postfile=FILENAME"], "Execute Python file after main file"),
 OE(["-w", "--pause-at-end"], "Prompt at the ending of processing"),
 OE(["-l", "--relative-path"], "Add path of EmPy script to sys.path", var='relativePath'),
-OE(["--no-callback-error"], "Custom markup with no callback is ignored"),
+OE(["--replace-newlines"], "Replace expression newlines with spaces"),
 OE(["--no-replace-newlines"], "Don't replace expression newlines with spaces"),
+OE(["--ignore-bangpaths"], "Treat bangpaths as comments"),
 OE(["--no-ignore-bangpaths"], "Don't treat bangpaths as comments"),
-OE(["--no-expand-user"], "Don't expand user constructions in filenames"),
-OE(["--no-auto-validate-icons"], "Don't auto-validate icons"),
+OE(["--expand-user"], "Expand user constructions (~user) in paths"),
+OE(["--no-expand-user"], "Don't expand user constructions in paths"),
+OE(["--auto-validate-icons"], "Auto-validate icons on first use"),
+OE(["--no-auto-validate-icons"], "Don't auto-validate icons on first use"),
 OE(["--none-symbol"], "String to write when expanding None", var='noneSymbol'),
-OE(["--no-none-symbol"], "Write nothing when expanding None (default)"),
+OE(["--no-none-symbol"], "Write nothing when expanding None"),
 OE(["--starting-line"], "Line number to start with", var='startingLine'),
 OE(["--starting-column"], "Column number to start with", var='startingColumn'),
 OE(["--emoji-modules"], "Comma-separated list of emoji modules to try\n", var='emojiModuleNames', fun=lambda x: ','.join(x)),
@@ -537,8 +542,8 @@ E("@$ EXPRESSION $ [DUMMY] $", "Evaluates to @$ EXPRESSION $ EXPANSION $"),
 E("@{ STATEMENTS }", "Statements are executed for side effects"),
 E("@[ CONTROL ]", "Control markups: if E; elif E; for N in E;\n"
                   "while E; try; except E as N; finally;\n"
-                  "continue; break; else; defined N; def F(...);\n"
-                  "end X"),
+                  "continue; break; else; with E as N; match E;\n"
+                  "case E; defined N; def F(...); end X"),
 E("@\\ ESCAPE_CODE", "A C-style escape sequence"),
 E("@^ CHAR DIACRITIC(S)", "A two-part diacritic sequence\n", ex="e' for an e with acute accent"),
 E("@| ICON", "A custom icon sequence\n", ex="'( for a single open curly quote"),
@@ -669,7 +674,7 @@ E("setContextLine(line)", "Set the line number of the current context"),
 E("setContextColumn(column)", "Set the column number of the current context"),
 E("setContextData(...)", "Set any of the name, line, column number"),
 E("restoreContext(context)", "Replace the top context with an existing one"),
-E("removeFinalizers()", "Remove all finalizers"),
+E("clearFinalizers()", "Clear all finalizers"),
 E("appendFinalizer(finalizer)", "Append function to be called at shutdown"),
 E("prependFinalizer(finalizer)", "Prepend function to be called at shutdown"),
 E("getGlobals()", "Retrieve this interpreter's globals"),
@@ -748,10 +753,13 @@ The following keyword arguments for the Interpreter constructor are supported
 E("argv", "The system arguments to use ['<->']"),
 E("callback", "A custom callback to register [None]"),
 E("config", "The configuration object [default]"),
+E("core", "The core to use for this interpreter [Core()]"),
+E("definerFunc", "Interpreter `@[def]` definition function [Python]"),
 E("dispatcher", "Dispatch errors or raise to caller? [True]"),
-E("evalFunc", "Function to evaluate expressions [eval]"),
-E("execFunc", "Function to execute statements [exec]"),
+E("evalFunc", "Interpreter expression evaluation function [eval]"),
+E("execFunc", "Interpreter statement execution function [exec]"),
 E("executable", "The path to the EmPy executable [\".../em.py\"]"),
+E("extension", "The extension to automatically install [None]"),
 E("filespec", "A 3-tuple of the input filename, mode, and buffering [None]"),
 E("filters", "The list of filters to install [[]]"),
 E("globals", "The globals dictionary to use [{}]"),
@@ -760,9 +768,10 @@ E("hooks", "The list of hooks to install [[]]"),
 E("ident", "The identifier for the interpreter [None]"),
 E("immediately", "Declare the interpreter ready after initialization? [True]"),
 E("input", "The input file to use for interactivity [sys.stdin]"),
+E("matcherFunc", "Interpreter `@[match]` matcher function [Python]"),
 E("output", "The output file to use [sys.stdout]"),
 E("root", "The root interpreter context filename ['<root>']"),
-E("serializerFunc", "Function to serialize objects [str]"),
+E("serializerFunc", "Interpreter serializer function [str]"),
 ]))
 
     usage.add(ConfigSection(
@@ -803,7 +812,7 @@ E("hasFixedBuffering()", "Is the buffering set to fixed?"),
 E("createFactory([tokens])", "Create token factory"),
 E("adjustFactory()", "Adjust token factory for non-default prefix"),
 E("getFactory([tokens], [force])", "Get a token factory"),
-E("restFactory()", "Clear the current token factory"),
+E("resetFactory()", "Clear the current token factory"),
 E("hasBinary()", "Is binary (Unicode) support enabled?"),
 E("enableBinary(...)", "Enable binary (Unicode) support"),
 E("disableBinary()", "Disable binary (Unicode) support"),
